@@ -1,5 +1,5 @@
 import logging
-from yaclipy import SubCmds
+from yaclipy import sub_cmds
 
 log = logging.getLogger('clipy-main')
 
@@ -24,7 +24,7 @@ def deploy():
 
 
 
-@SubCmds(shout, say)
+@sub_cmds(shout, say)
 def main(*, verbose__v=False, quiet__q=False, target__t=''):
     ''' This is the sole entrypoint for this project.
     
