@@ -1,9 +1,7 @@
 import pytest
 from yaclipy.docs import short_cmd_list
-from yaclipy.cmd_dfn import CmdDfn, SubCmds
+from yaclipy.cmd_dfn import CmdDfn, sub_cmds
 from print_ext import Printer
-from .has_cmds import HasCmds
-
 
 
 def test_short_cmd_list(capfd):
@@ -19,14 +17,16 @@ def test_short_cmd_list(capfd):
 
     def cob(*args):
         pass
-
-    obj = SubCmds(bob_=bob, z=3, a_long_name=x, name={'a':'b'}, _hidden=cob)
-    Printer()(short_cmd_list(CmdDfn.scrape(obj)))
+    @sub_cmds(bob_=bob, a_long_name=x)
+    def f():pass
+    cmd = CmdDfn('f',f)
+    Printer()(short_cmd_list(cmd.sub_cmds()))
     out, _ = capfd.readouterr()
     print(out)
     assert(out == '\n * a-long-name About time.\n\n * bob         Short description.\n\n')
 
 
+@pytest.mark.xfail(reason='Not implemented')
 def test_doc_testing():
     assert(False)
     
\ No newline at end of file
